OC.L10N.register(
    "tasks",
    {
    "Tasks" : "工作項目",
    "Important" : "重要",
    "Today" : "今天",
    "Week" : "週",
    "All" : "所有",
    "Current" : "目前",
    "Completed" : "完成",
    "Delete" : "刪除",
    "Cancel" : "取消",
    "Change sort order" : "改變分類順序",
    "Default" : "預設",
    "Due date" : "到期日",
    "Start date" : "開始日期",
    "Priority" : "優先",
    "Manually" : "手動",
    "Alphabetically" : "字母",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 完成任務"],
    "Tomorrow" : "明天",
    "Set start date" : "指定開始日期",
    "Set due date" : "指定到期日",
    "All day" : "全天",
    "Task not found!" : "找不到任務!",
    "Edit" : "編輯",
    "Download" : "下載",
    "Save" : "儲存",
    "New List" : "新列表",
    "An empty name is not allowed." : "不允許空白的名稱.",
    "Settings" : "設定",
    "Hidden" : "隱藏",
    "Visible" : "顯示",
    "Automatic" : "自動"
},
"nplurals=1; plural=0;");
